@@ -35,14 +35,13 @@ import os
 import shutil
 import tempfile
 
-from datetime import date, datetime
-
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.core import mail
 from django.core.management import call_command
 from django.db.models.query_utils import Q
 from django.test import SimpleTestCase, TestCase
+from django.utils import timezone
 
 from checklists.models import Location, Species, Checklist, Entry, \
     Observer, Protocol, Method, Map, Activity, Age, Sex, Detail, Filter
@@ -229,6 +228,14 @@ class LoadTestCase(TestCase):
             call_command('load_checklists')
         self.assertTrue(Checklist.objects.exists())
 
+    def test_file_deleted(self):
+        save_data(self.directory, "checklist.json", downloaded_checklist())
+        with mock.patch.object(settings,
+                               'CHECKLISTS_DOWNLOAD_DIR', self.directory):
+            call_command('load_checklists')
+        path = os.path.join(self.directory, "checklist.json")
+        self.assertFalse(os.path.exists(path))
+
     def test_entry_without_identifier(self):
         checklist = downloaded_checklist()
         entry = checklist['entries'][0]
@@ -516,12 +523,12 @@ class StatusReportTestCase(SimpleTestCase):
 
     def test_status_report_date(self):
         contents = mail.outbox[0].body
-        expected = "Date: %s" % date.today().strftime("%d-%m-%Y")
+        expected = "Date: %s" % timezone.now().date().strftime("%d-%m-%Y")
         self.assertTrue(expected in contents)
 
     def test_status_report_time(self):
         contents = mail.outbox[0].body
-        expected = "Time: %s" % datetime.now().strftime("%H:%M")
+        expected = "Time: %s" % timezone.now().strftime("%H:%M")
         self.assertTrue(expected in contents)
 
     def test_status_report_loaded_section(self):
@@ -879,3 +886,25 @@ class ErrorOnLoadTestCase(TestCase):
 
         sections = mail.outbox[0].body.split('+-')
         self.assertTrue("Traceback (most recent call last)" in sections[-1])
+
+    def test_file_not_deleted(self):
+
+        data = {
+            "location": {
+                "identifier": "L12345",
+                "name": "Cape Clear",
+                "county": "Cork",
+                "region": "South-West",
+                "country": "Eire",
+                "lat": 51.433333,
+                "lon": -9.5
+            }
+        }
+        save_data(self.directory, "checklist.json", data)
+
+        with mock.patch.object(
+                settings, 'CHECKLISTS_REPORT_RECIPIENTS', 'admins@example.com'):
+            call_command('load_checklists', dir=self.directory)
+
+        path = os.path.join(self.directory, "checklist.json")
+        self.assertTrue(os.path.exists(path))
